==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/TileGeneratorMapImageryDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GeographicMapImageryDescriptionMetadata } from "./GeographicMapImageryDescriptionMetadata";
import { TileGeneratorMapImageryDescription } from "./TileGeneratorMapImageryDescription";
/**
 * @hidden
 */
export let TileGeneratorMapImageryDescriptionMetadata = /*@__PURE__*/ (() => {
    class TileGeneratorMapImageryDescriptionMetadata extends Base {
        static b(a) {
            if (TileGeneratorMapImageryDescriptionMetadata.a == null) {
                TileGeneratorMapImageryDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                TileGeneratorMapImageryDescriptionMetadata.c(TileGeneratorMapImageryDescriptionMetadata.a);
            }
            if (a.k(TileGeneratorMapImageryDescriptionMetadata.a)) {
                return;
            }
            a.aa(TileGeneratorMapImageryDescriptionMetadata.a);
        }
        static c(a) {
            GeographicMapImageryDescriptionMetadata.c(a);
            a.item("TileGenerator", "ExportedType");
        }
        static d(a) {
            TileGeneratorMapImageryDescriptionMetadata.b(a);
            a.ac("TileGeneratorMapImagery", () => new TileGeneratorMapImageryDescription());
            a.ab("TileGeneratorMapImagery", TileGeneratorMapImageryDescriptionMetadata.a);
        }
    }
    TileGeneratorMapImageryDescriptionMetadata.$t = /*@__PURE__*/ markType(TileGeneratorMapImageryDescriptionMetadata, 'TileGeneratorMapImageryDescriptionMetadata');
    TileGeneratorMapImageryDescriptionMetadata.a = null;
    return TileGeneratorMapImageryDescriptionMetadata;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/TileGeneratorMapImageryDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GeographicMapImageryDescriptionMetadata } from "./GeographicMapImageryDescriptionMetadata";
import { TileGeneratorMapImageryDescription } from "./TileGeneratorMapImageryDescription";
/**
 * @hidden
 */
export let TileGeneratorMapImageryDescriptionMetadata = /*@__PURE__*/ (() => {
    class TileGeneratorMapImageryDescriptionMetadata extends Base {
        static b(a) {
            if (TileGeneratorMapImageryDescriptionMetadata.a == null) {
                TileGeneratorMapImageryDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                TileGeneratorMapImageryDescriptionMetadata.c(TileGeneratorMapImageryDescriptionMetadata.a);
            }
            if (a.k(TileGeneratorMapImageryDescriptionMetadata.a)) {
                return;
            }
            a.ac(TileGeneratorMapImageryDescriptionMetadata.a);
        }
        static c(a) {
            GeographicMapImageryDescriptionMetadata.c(a);
            a.item("TileGenerator", "ExportedType");
        }
        static d(a) {
            TileGeneratorMapImageryDescriptionMetadata.b(a);
            a.ae("TileGeneratorMapImagery", () => new TileGeneratorMapImageryDescription());
            a.ad("TileGeneratorMapImagery", TileGeneratorMapImageryDescriptionMetadata.a);
        }
    }
    TileGeneratorMapImageryDescriptionMetadata.$t = /*@__PURE__*/ markType(TileGeneratorMapImageryDescriptionMetadata, 'TileGeneratorMapImageryDescriptionMetadata');
    TileGeneratorMapImageryDescriptionMetadata.a = null;
    return TileGeneratorMapImageryDescriptionMetadata;
})();
